@@ -8,12 +8,15 @@
 #include <KOSMIndoorMap/MapLoader>
 
 #include <osm/datatypes.h>
-#include <osm/xmlwriter.h>
+#include <osm/io.h>
 
 #include <QCommandLineParser>
 #include <QCoreApplication>
 #include <QDebug>
 #include <QFile>
+#include <QtPlugin>
+
+Q_IMPORT_PLUGIN(OSM_XmlIOPlugin)
 
 using namespace KOSMIndoorMap;
 
@@ -98,6 +101,11 @@ int main(int argc, char **argv)
         qCritical() << f.errorString();
         return 1;
     }
-    OSM::XmlWriter::write(data.dataSet(), &f);
+    auto writer = OSM::IO::writerForFileName(f.fileName());
+    if (!writer) {
+        qCritical() << "no file writer for requested format:" << f.fileName();
+        return 1;
+    }
+    writer->write(data.dataSet(), &f);
     return 0;
 }
